==> bcc-core-api-node-sdk-1.12.0.tgz: package/lib/esm/api/roleAssignmentsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
export class RoleAssignmentsClient {
    constructor(basePath, auth, queryOptions) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/roleAssignments",
            auth: auth,
            writeTypeName: "RoleAssignmentWrite",
            singleResponseTypeName: "WrappedRoleAssignment",
            multipleResponseTypeName: "WrappedWithMetaArrayRoleAssignment",
            patchTypeName: "RoleAssignmentWrite",
            queryOptions: queryOptions,
        });
    }
    create(affiliation) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(affiliation);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    patch(id, affiliation) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.patch(id, affiliation);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
}

==> bcc-core-api-node-sdk-1.16.0.tgz: package/lib/esm/api/roleAssignmentsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
export class RoleAssignmentsClient {
    constructor(basePath, auth, queryOptions) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/roleAssignments",
            auth: auth,
            writeTypeName: "RoleAssignmentWrite",
            singleResponseTypeName: "WrappedRoleAssignment",
            multipleResponseTypeName: "WrappedWithMetaArrayRoleAssignment",
            queryOptions: queryOptions,
        });
    }
    create(roleAssignments) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(roleAssignments);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    update(id, roleAssignments) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.update(id, roleAssignments);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
}
